@@ -65,6 +65,7 @@ Spec1rProcpar <- list (
     ZFFAC=4,                   # Max factor for Zero Filling 
     LINEBROADENING=TRUE,       # Line Broading
     TSP=FALSE,                 # PPM referencing
+    O1RATIO=1,                 # Fractionnal value of the Sweep Width for PPM calibration if not based on the parameter of the spectral region center (O1)
     RABOT=FALSE,               # Zeroing of Negative Values 
     OPTPHC0=TRUE,              # Zero order phase optimization
     OPTPHC1=FALSE,             # First order phase optimization
@@ -868,13 +869,21 @@ Spec1rProcpar <- list (
     m <- proc$SI
     SW <- spec$acq$SW
     SWH <- spec$acq$SWH
-    O1 <- spec$acq$O1
+    if (param$O1RATIO==1) {
+        O1 <- spec$acq$O1
+    } else {
+        O1 <- SWH*param$O1RATIO
+    }
     spec$dppm <- SW/(m-1)
     spec$pmin <- 1 - round(SW/5) # 5 - 0.5*SW
     
     repeat {
        if (toupper(spec$acq$INSTRUMENT) %in% c("JEOL","VARIAN")) {
-          spec$pmin <- spec$acq$OFFSET - SW/2
+          if (param$O1RATIO==1) {
+              spec$pmin <- spec$acq$OFFSET - SW/2
+          } else {
+              spec$pmin <- SW*param$O1RATIO - SW/2
+          }
           break
        }
        if (spec$acq$NUC %in% c('1H','H1') ) {
